"""
AlphaStation - A minimal placeholder Python package.
"""

__version__ = "0.1.0"
__author__ = "AlphaStation"
__email__ = "alphastation@example.com"

from .core import AlphaStation, alpha_function

__all__ = ["AlphaStation", "alpha_function", "__version__"] 